@@ -1,9 +1,8 @@
-#' @title Test for Evaluating Negligible Effects Between a Predictor and Outcome in a Multiple Regression Model
+#' @title Test for Evaluating Negligible Effect Between a Predictor and Outcome in a Multiple Regression Model
+#'
+#' @description This function evaluates whether a certain predictor variable in a multiple regression model can be considered statistically and practically negligible according to a predefined interval. i.e., minimally meaningful effect size (MMES)/smallest effect size of interest (SESOI). Where the effect tested is the relationship between the predictor of interest and the outcome variable, holding all other predictors constant.
+#'
 #'
-#' @description This function tests whether a certain predictor variable in a multiple regression model can be considered statistically and practically negligible according to a predefined interval. i.e., minimally meaningful effect size,MMES/smallest effect size of interest, SESOI (where
-#' in this case, the effect is the relationship between the predictor of interest and the outcome variable, holding the other predictors constant). Developed from the Anderson-Hauck (1983) and Schuirmann's (1987) Two One-Sided Test (TOST) equivalence testing procedures.
-#' 
-#' 
 #' @param data a data.frame or matrix which includes the variables considered in the regression model
 #' @param formula an argument of the form y~x1+x2...xn which defines the regression model
 #' @param predictor name of the variable/predictor upon which the test will be applied
@@ -23,16 +22,55 @@
 #' @param saveplots FALSE for no, "png" and "jpeg" for different formats
 #' @param seed to reproduce previous analyses using bootstrapping, the user can set their seed of choice
 #' @param ... additional arguments to be passed
-#' 
-#' 
-#' @return returns a \code{list} containing each analysis and 
-#' their respective statistics and decision
 #'
-#' @author Udi Alter \email{udialter@@yorku.ca} and
-#'   Alyssa Counsell \email{a.counsell@@ryerson.ca}
+#'
+#' @return A \code{list} containing the following:
+#' \itemize{
+#'   \item \code{formula} The regression model
+#'   \item \code{effect} Specifying if effect size is in standardized or unstandardized units
+#'   \item \code{test} Test type, i.e., Anderson-Hauck (AH) or Two One-Sided Tests (TOST)
+#'   \item \code{t.value} t test statistic. If TOST was specified, only the smaller of the t values will be presented
+#'   \item \code{df} Degrees of freedom associated with the test statistic
+#'   \item \code{n} Sample size
+#'   \item \code{p.value} p value associated with the test statistic. If TOST was specified, only the larger of the p values will be presented
+#'   \item \code{eil} Lower bound of the negligible effect (equivalence) interval
+#'   \item \code{eiu} Upper bound of the negligible effect (equivalence) interval
+#'   \item \code{predictor} Variable name of the predictor in question
+#'   \item \code{b} Effect size of the specified predictor
+#'   \item \code{se} Standard error associated with the effect size point estimate (in the same units)
+#'   \item \code{l.ci} Lower bound of the 1-alpha CI for the effect size
+#'   \item \code{u.ci} Upper bound of the 1-alpha CI for the effect size
+#'   \item \code{pd} Proportional distance
+#'   \item \code{pd.l.ci} Lower bound of the 1-alpha CI for the PD
+#'   \item \code{pd.u.ci} Upper bound of the 1-alpha CI for the PD
+#'   \item \code{seed} Seed identity if bootstrapping is used
+#'   \item \code{decision} NHST decision
+#'   \item \code{alpha} Nominal Type I error rate
+#' }
+#' @export
+#' @details This function evaluates whether a certain predictor variable in a multiple regression model can be considered statistically and practically negligible according to a predefined interval. i.e., minimally meaningful effect size (MMES)/smallest effect size of interest (SESOI). Where the effect tested is the relationship between the predictor of interest and the outcome variable, holding all other predictors constant.
+#'
+#' Unlike the most common null hypothesis significance tests looking to detect a difference or the existence of an effect statistically different than zero, in negligible effect testing, the hypotheses are flipped: In essence, H0 states that the effect is non-negligible, whereas H1 states that the effect is in fact statistically and practically negligible.
+#'
+#' The statistical tests are based on Anderson-Hauck (1983) and Schuirmann's (1987) Two One-Sided Test (TOST) equivalence testing procedures; namely addressing the question of whether the estimated effect size (and its associated uncertainty) of a predictor variable in a multiple regression model is smaller than the what the user defines as negligible effect size. Defining what is considered negligible effect is done by specifying the negligible (equivalence) interval: its upper (eiu) and lower (eil) bounds.
+#'
+#' The negligible (equivalence) interval should be set based on the context of the research. Because the predictor's effect size can be in either standardized or unstandardized units, setting eil and eiu is a matter of determining what magnitude of the relationship between predictor and outcome in either standardized or unstandardized units is the minimally meaningful effect size (MMES) given the context of the research.
+#'
+#' It is necessary to be consistent with the units of measurement. For example, unstandardized negligible interval bounds (i.e., eil and eiu) must only be used when std = FALSE (default). If the effect size (b), standard error (se), and sample size (n) are entered manually as arguments (i.e., without the dataset), these should also be in the same units of measurements. Whereas if the user prefers to specify eiu and eil in standardized unites, std = TRUE should be specified. In which case, any units entered into the function must also be in standardized form. Mixing unstandardized and standardized units would yield inaccurate results and likely lead to invalid conclusions. Thus, users must be cognizant of the measurement units of the negligible interval.
+#'
+#' There are two main approaches to using neg.reg. The first (and more recommended) is by inserting a dataset ('data' argument) into the function. If the user/s have access to the dataset, they should use the following set of arguments: data, formula, predictor, bootstrap (optional), nboot (optional), and seed (optional). However, this function also accommodates cases where no dataset is available. In this case, users should use the following set of arguments instead: b, se, n, and nop. In either situation, users must specify the negligible interval bounds (eiu and eil). Other optional arguments and features include: alpha, std, test, plots, and saveplots.
+#'
+#' The proportional distance (PD; effect size/eiu) estimates the proportional distance of the estimated effect to eiu, and acts as an alternative effect size measure.
+#'
+#' The confidence interval for the PD is computed via bootstrapping (percentile bootstrap), unless the user does not insert a dataset. In which case, the PD confidence interval is calculated by dividing the upper and lower CI bounds for the effect size estimate by the absolute value of the negligible interval bounds.
+#'
+#'
+#' @author Udi Alter \email{udialter@@gmail.com} and
+#'   Alyssa Counsell \email{a.counsell@@ryerson.ca} and
+#'   Rob Cribbie \email{cribbie@@yorku.ca}
 #' @export neg.reg
-#' 
-#' 
+#'
+#'
 #' @examples
 #' # Negligible Regression Coefficient (equivalence interval: -.1 to .1)
 #' pr1 <- stats::rnorm(20)
@@ -41,14 +79,14 @@
 #' dat <- data.frame(pr1,pr2,dp)
 #' # dataset available (unstandardized coefficients, AH procedure):
 #' neg.reg(formula=dp~pr1+pr2,data=dat,predictor=pr1,eil=-.1,eiu=.1,nboot=50)
-#' 
-
-
+#' neg.reg(b=.03, se=.01, nop=3,n=500, eil=-.1,eiu=.1)
+#' # end.
+#'
 neg.reg <- function(data=NULL, formula=NULL, predictor=NULL, #input for full dataset
                     b = NULL, se=NULL, nop=NULL, n=NULL,     #input for no dataset
                     eil, eiu, alpha=.05, test="AH", std=FALSE,
-                    bootstrap=TRUE, nboot=1000, #input needed for both
-                    plots = TRUE, saveplots = FALSE,seed=NA,...)#input needed for both
+                    bootstrap=TRUE, nboot=1000,
+                    plots = TRUE, saveplots = FALSE, seed=NA,...) # optional input for both
   {
 
 
@@ -98,7 +136,7 @@ neg.reg <- function(data=NULL, formula=NULL, predictor=NULL, #input for full dat
     }
 
     data <- extract.formula.vars(formula,data)
-    samplesize <- nrow(data) # determining the sample size
+    n  <- nrow(data) # determining the sample size
     model <- stats::lm(formula, data)
     model.results <- summary(model)
 
@@ -142,15 +180,17 @@ neg.reg <- function(data=NULL, formula=NULL, predictor=NULL, #input for full dat
       beta.coef<-numeric(nboot)
       propdis.beta<-numeric(nboot)
 
+
       if(is.na(seed)){
-      seed <- sample(.Random.seed[1], size = 1)
+        if (!exists(".Random.seed")) stats::runif(1)
+        seed <- sample(.Random.seed[1], size = 1)
       } else {
         seed <- seed
         }
       set.seed(seed)
       for (i in 1:nboot) {
-        temp.data <- dplyr::sample_n(data,samplesize, replace = TRUE)
-        temp.std.data <- dplyr::sample_n(std.data,samplesize, replace = TRUE)
+        temp.data <- dplyr::sample_n(data,n , replace = TRUE)
+        temp.std.data <- dplyr::sample_n(std.data,n , replace = TRUE)
         temp.model <- stats::lm(formula, data = temp.data)
         temp.std.model <- stats::lm(formula, data = temp.std.data)
         # regression coefficients
@@ -272,8 +312,8 @@ neg.reg <- function(data=NULL, formula=NULL, predictor=NULL, #input for full dat
     ifelse(abs(t.value.1) <= abs(t.value.2), t.value <- t.value.1, t.value <- t.value.2) # finding the smaller t to present
     ifelse(p.value.1 >= p.value.2, p.value <- p.value.1, p.value <- p.value.2) # finding the larger p to present
 
-    ifelse(p.value.1 < alpha & p.value.2 < alpha, decision <- 'The null hypothesis that the regression coefficient is non-negligible can be rejected. A negligible effect is concluded. The null hypothesis that the direct effect (difference between the total and indirect effect) is non-negligible can be rejected. Substantial Mediation CAN be concluded. Be sure to interpret the magnitude (and precision) of the effect size.',
-           decision <-'The null hypothesis that the regression coefficient is non-negligible cannot be rejected. There is insufficient evidence to conclude a negligible effect. The null hypothesis that the direct effect (difference between the total and indirect effect) is non-negligible can be rejected. Substantial Mediation CAN be concluded. Be sure to interpret the magnitude (and precision) of the effect size.')
+    ifelse(p.value.1 < alpha & p.value.2 < alpha, decision <- 'The null hypothesis that the regression coefficient is non-negligible can be rejected. A negligible effect is concluded. Be sure to interpret the magnitude (and precision) of the effect size.',
+           decision <-'The null hypothesis that the regression coefficient is non-negligible cannot be rejected. There is insufficient evidence to conclude a negligible effect. Be sure to interpret the magnitude (and precision) of the effect size.')
   }
 
 
@@ -282,7 +322,7 @@ neg.reg <- function(data=NULL, formula=NULL, predictor=NULL, #input for full dat
   ret <- data.frame(  title = title,
                       subtitle = subtitle,
                       alpha = alpha,
-                      formula = deparse(formula),
+                      formula = deparse(formula, width.cutoff = 500),
                       effect = effect,
                       symb = symb,
                       bootstrap = bootstrap,
@@ -290,10 +330,11 @@ neg.reg <- function(data=NULL, formula=NULL, predictor=NULL, #input for full dat
                       test = test,
                       t.value = t.value,
                       df = df,
+                      n = n,
                       p.value = p.value,
                       decision = decision,
-                      eiu = eiu,
-                      eil = eil,
+                      eiu = round(eiu,3),
+                      eil = round(eil,3),
                       b = b,
                       se = se,
                       u.ci = u.ci,
@@ -313,6 +354,7 @@ neg.reg <- function(data=NULL, formula=NULL, predictor=NULL, #input for full dat
                       plots = plots,
                       saveplots=saveplots,
                       seed = seed,
+                      oe="Regression Coefficient",
                       withdata = withdata,
                       outcome = deparse(substitute(depname)))
   class(ret) <- "neg.reg"
@@ -321,45 +363,53 @@ return(ret)
 
 #' @rdname neg.reg
 #' @param x object of class \code{neg.reg}
-#' @return
+#' @param ... extra arguments
 #' @export
 #'
 print.neg.reg <- function(x,...) {
   ifelse(round(x$p.value,3) == 0, p.val <- " < 0.001", p.val <- paste(" = ", round(x$p.value,3), sep = ""))
   cat("\n\n")
   cat("***",x$title, "***\n\n")
+
   if (x$bootstrap == TRUE & x$withdata == TRUE) {
     cat(x$effect, " regression coefficient for ", x$predictor," and confidence interval using ", x$nboot," bootstrap iterations (random seed = ",x$seed,"):","\n",
         x$symb, " = ", round(x$b,3), ", ",x$perc.a, "% CI [",round(x$l.ci,3),", ",round(x$u.ci,3),"]" ,"\n",
-        "std. error = ", round(x$se,3), "\n", sep = "")
+        "std. error = ", round(x$se,3),  sep = "")
 
   } else {
   cat(x$effect, " regression coefficient for ", x$predictor,":", "\n",
       x$symb, " = ", round(x$b,3), ", ",x$perc.a, "% CI [",round(x$l.ci,3),", ",round(x$u.ci,3),"]" ,"\n",
-      "std. error = ", round(x$se,3), "\n", sep = "")
+      "std. error = ", round(x$se,3), sep = "")
   }
-  cat("**********************\n\n")
+
+  cat("\n\n**********************\n\n")
   cat(x$subtitle, "\n\n")
   cat("Equivalence interval: ","lower= ", x$eil, ", ", "upper= ", x$eiu, "\n", sep = "")
 
-  if(x$test == "TOST" & x$bootstrap == TRUE & x$withdata == TRUE){
-  cat(x$perc.2a,"% bootstrap-generated CI for the ",x$effect, " regression coefficient: [",round(x$l.ci.2a,3),", ",round(x$u.ci.2a,3),"]\n", sep = "")
-    }
-  else if(x$test == "TOST"){
-    if (x$withdata==FALSE | x$bootstrap == FALSE){
-    cat(x$perc.2a,"% CI for the ",x$effect, " regression coefficient: [",round(x$l.ci.2a,3),", ",round(x$u.ci.2a,3),"]\n", sep = "")
-    } }
+  if(x$test == "TOST"){
+
   cat("t(",x$df,") = ",round(x$t.value,3)," (smallest magnitude t value out of t1/t2)","\n","p",p.val,"\n", sep = "")
   cat("NHST decision: ", x$decision,"\n", sep = "")
+  }
+  if (x$test=="AH") {
+    cat("Anderson-Hauck T statistic = ",round(x$t.value,3),"\n","p",p.val,"\n", sep = "")
+    cat("NHST decision: ", x$decision,"\n", sep = "")
+  }
+
   if (x$test == "AH" & x$plots == TRUE){
     cat("\n*Note that NHST decisions using the AH procedure may not match TOST NHST results or the Symmetric CI Approach at 100*(1-2\u03B1)% illustrated in the plots. \n")
   }
-  cat("**********************\n\n")
+  cat("\n**********************\n\n")
+  cat("Proportional Distance","\n\n")
+  cat("Proportional distance:", round(x$pd,3),"\n")
+  cat(x$perc.a, "% confidence interval for the proportional distance: (",round(x$pd.l.ci,3), ", ",round(x$pd.u.ci,3),")","\n\n",sep="")
+  cat("*Note that the confidence interval for the proportional distance may not be precise with small sample sizes","\n")
+  cat("*******************", "\n\n")
 
 
 if (x$plots == TRUE) {
   plot(NA, axes=F,
-       xlim = c(min(x$l.ci,x$eil)-max(x$u.ci-x$l.ci, x$eiu-x$eil)/10, max(x$u.ci,x$eiu)+max(x$u.ci-x$l.ci, x$eiu-x$eil)/10),
+       xlim = c(min(x$l.ci,x$eil)-max(x$u.ci-x$l.ci, x$eiu-x$eil)/5, max(x$u.ci,x$eiu)+max(x$u.ci-x$l.ci, x$eiu-x$eil)/5),
        ylim = c(0,1),
        yaxt='n',
        ylab="",
@@ -371,15 +421,15 @@ if (x$plots == TRUE) {
   graphics::abline(v=x$eiu, lty=2, col = "red") # mark the upper eq. bound
   graphics::abline(v=x$eil, lty=2, col = "red") # mark the lower eq. bound
   graphics::segments(x$l.ci.2a,0.3,x$u.ci.2a,0.3, lwd=3) # plotting the 90% CI for the predictor estimate
-  graphics::text(x$eiu+0.01,.7,labels=paste("upper equivalence bound is ",x$eiu, sep = ""),srt=270,pos=3, offset = 0, col = "red", cex=0.7) # text for eq. bound line (upper)
-  graphics::text(x$eil-0.01,.7,labels=paste("lower equivalence bound is ",x$eil, sep = "") ,srt=90,pos=3, offset = 0, col = "red", cex=0.7) # text for eq. bound line (lower)
-  graphics::text(x$eiu+0.02,.01,x$eiu,srt=0,pos=3, offset = .5, col = "red") # writing the eq. interval bound value (upper)
-  graphics::text(x$eil-0.02,.01,x$eil,srt=0,pos=3, offset = .5, col = "red") # writing the eq. interval bound value (lower)
-  graphics::text(x$b,.37,round(x$b, digits = 3),srt=0) # writing the predictor point estimate value
+  graphics::text(x$eiu+0.01,.7,labels=paste("upper negligible effect bound", sep = ""),srt=270,pos=3, offset = 0, col = "red", cex=0.7) # text for eq. bound line (upper)
+  graphics::text(x$eil-0.01,.7,labels=paste("lower negligible effect bound", sep = "") ,srt=90,pos=3, offset = 0, col = "red", cex=0.7) # text for eq. bound line (lower)
+  graphics::text(x$eiu+0.02,0,round(x$eiu,2),srt=0,pos=3, offset = .15, col = "red") # writing the eq. interval bound value (upper)
+  graphics::text(x$eil-0.02,0,round(x$eil,2),srt=0,pos=3, offset = .15, col = "red") # writing the eq. interval bound value (lower)
+  graphics::text(x$b,.37,round(x$b, digits = 2),srt=0) # writing the predictor point estimate value
   graphics::text(x= x$b,y=.36, labels= x$symb, srt=1, pos = 2, offset = 2.3)# adding text to indicate above line
   graphics::text(x= x$b,y=.36, labels="  =", srt=1, pos = 2, offset = 1.5) # adding text to indicate above line
-  graphics::text(x$u.ci.2a,.25,round(x$u.ci.2a, digits = 3),pos =1, offset = .1, col = "black") # writing the 90% CI upper limit value for the predictor estimate
-  graphics::text(x$l.ci.2a,.25,round(x$l.ci.2a, digits = 3), pos =1, offset = .1,col = "black") # writing the 90% CI lower limit value for the predictor estimate
+  graphics::text(x$u.ci.2a,.27,round(x$u.ci.2a, digits = 2),pos =4, offset = .01, col = "black") # writing the 90% CI upper limit value for the predictor estimate
+  graphics::text(x$l.ci.2a,.27,round(x$l.ci.2a, digits = 2), pos =2, offset = .01,col = "black") # writing the 90% CI lower limit value for the predictor estimate
   graphics::axis(side=1, pos=0, lwd.ticks=0)
   if (!(x$saveplots == FALSE)) {
     if (x$saveplots == "png"){
@@ -390,7 +440,7 @@ if (x$plots == TRUE) {
 
   #grDevices::dev.off()
 
-neg.pd(effect=x$b, PD = x$pd, EIsign=x$EIc, PDcil=x$pd.l.ci, PDciu=x$pd.u.ci, cil=x$l.ci.2a,
-                      ciu=x$u.ci.2a, Elevel=100*(1-2*x$alpha), Plevel=100*(1-x$alpha), save = x$saveplots)
+  neg.pd(effect=x$b, PD = x$pd, eil=x$eil, eiu=x$eiu, PDcil=x$pd.l.ci, PDciu=x$pd.u.ci, cil=x$l.ci.2a,
+         ciu=x$u.ci.2a, Elevel=100*(1-2*x$alpha), Plevel=100*(1-x$alpha), save = x$saveplots, oe=x$oe)
  }
 }
